@@ -143,9 +143,6 @@ enum {
   ATTR_PROTECTED  = 0x20000000u,
   ATTR_FRAMED     = 0x0010000000000000u,
 
-  GRAPH_MASK      = 0x00000F0000000000u,
-  ATTR_GRAPH_SHIFT = 40,
-
   FONTFAM_MASK    = 0x000F000000000000u,
   ATTR_FONTFAM_SHIFT = 48,
 
@@ -176,7 +173,10 @@ enum {
   DATTR_MASK      = TATTR_RIGHTCURS | TATTR_PASCURS | TATTR_ACTCURS
                     | DATTR_STARTRUN
   // unassigned bits:
-  // - none
+  //              = 0x0000080000000000u,
+  //              = 0x0000040000000000u,
+  //              = 0x0000020000000000u,
+  //              = 0x0000010000000000u,
 };
 
 /* Line attributes.
@@ -548,7 +548,8 @@ struct term {
   bool bell_popup;   // xterm: popOnBell;    switchable with CSI ? 1043 h/l
   bool wheel_reporting_xterm; // xterm: alternateScroll
   bool wheel_reporting;       // similar, but default true
-  bool app_wheel;             // format for wheel_reporting
+  bool app_wheel;             // dedicated wheel codes instead of cursor codes
+  bool alt_wheel;             // add Alt modifier to wheel cursor codes
   int  modify_other_keys;
   bool newline_mode;
   bool report_focus;
@@ -584,6 +585,9 @@ struct term {
   uchar esc_mod;  // Modifier character in escape sequences
 
   uchar vt52_mode;
+  bool save_autowrap;
+  bool save_rev_wrap;
+  bool emoji_width;
 
   uint csi_argc;
   uint csi_argv[32];
